@@ -2,7 +2,7 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 
     SPDX-FileCopyrightText: 2003 Brian Thomas <thomas@mail630.gsfc.nasa.gov>
-    SPDX-FileCopyrightText: 2004-2020 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
+    SPDX-FileCopyrightText: 2004-2021 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
 */
 
 #ifndef JAVAANTCODEDOCUMENT_H
@@ -34,7 +34,7 @@ public:
      */
     virtual ~JavaANTCodeDocument ();
 
-    QString getPath ();
+    QString getPath () const;
 
     void updateContent();
 
