@@ -1,12 +1,7 @@
-/***************************************************************************
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *  copyright (C) 2003-2014                                                *
- *  Umbrello UML Modeller Authors <umbrello-devel@kde.org>                 *
- ***************************************************************************/
+/*
+    SPDX-License-Identifier: GPL-2.0-or-later
+    SPDX-FileCopyrightText: 2003-2020 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
+*/
 
 #include "umlforeignkeyconstraintdialog.h"
 
@@ -30,11 +25,12 @@
 #include "icon_utils.h"
 
 #include <kcombobox.h>
+#if QT_VERSION < 0x050000
 #include <kdialogbuttonbox.h>
+#endif
 #include <klineedit.h>
-#include <klocale.h>
-#include <kmessagebox.h>
-#include <kvbox.h>
+#include <KLocalizedString>
+#include <KMessageBox>
 
 #include <QApplication>
 #include <QGridLayout>
@@ -45,8 +41,6 @@
 #include <QTreeWidget>
 #include <QVBoxLayout>
 
-typedef QPair<UMLEntityAttribute*, UMLEntityAttribute*> EntityAttributePair;
-
 /**
  *  Sets up the UMLForeignKeyConstraintDialog
  *
@@ -157,11 +151,13 @@ bool UMLForeignKeyConstraintDialog::apply()
 {
     // set the Referenced Entity
     QString entityName = m_GeneralWidgets.referencedEntityCB->currentText();
-    UMLObject* uo = m_doc->findUMLObject(entityName, UMLObject::ot_Entity);
+    UMLObject* uo = m_doc->findUMLObjectRecursive(Uml::ModelType::EntityRelationship,
+                                                  entityName,
+                                                  UMLObject::ot_Entity);
 
-    UMLEntity* ue = static_cast<UMLEntity*>(uo);
+    UMLEntity* ue = uo->asUMLEntity();
 
-    if (ue == NULL) {
+    if (ue == 0) {
         uDebug() << " Could not find UML Entity with name " << entityName;
         return false;
     }
@@ -188,6 +184,9 @@ bool UMLForeignKeyConstraintDialog::apply()
     // set the name
     m_pForeignKeyConstraint->setName(m_GeneralWidgets.nameT->text());
 
+    // propagate changes to tree view
+    m_pForeignKeyConstraint->emitModified();
+
     return true;
 }
 
@@ -197,11 +196,15 @@ bool UMLForeignKeyConstraintDialog::apply()
 void UMLForeignKeyConstraintDialog::setupGeneralPage()
 {
     //setup General page
-    KVBox * page = new KVBox();
+    QWidget* page = new QWidget();
+    QVBoxLayout* topLayout = new QVBoxLayout();
+    page->setLayout(topLayout);
+
     pageGeneral = createPage(i18nc("general page title", "General"), i18n("General Settings"),
                              Icon_Utils::it_Properties_General, page);
 
-    m_GeneralWidgets.generalGB = new QGroupBox(i18nc("general group title", "General"), page);
+    m_GeneralWidgets.generalGB = new QGroupBox(i18nc("general group title", "General"));
+    topLayout->addWidget(m_GeneralWidgets.generalGB);
 
     QGridLayout* generalLayout = new QGridLayout(m_GeneralWidgets.generalGB);
     generalLayout->setSpacing(spacingHint());
@@ -211,29 +214,29 @@ void UMLForeignKeyConstraintDialog::setupGeneralPage()
                                        m_GeneralWidgets.nameL, i18nc("label for entering name", "Name"),
                                        m_GeneralWidgets.nameT);
 
-    m_GeneralWidgets.referencedEntityL = new QLabel(i18n("Referenced Entity"), page);
+    m_GeneralWidgets.referencedEntityL = new QLabel(i18n("Referenced Entity"));
     generalLayout->addWidget(m_GeneralWidgets.referencedEntityL, 1, 0);
 
-    m_GeneralWidgets.referencedEntityCB = new KComboBox(page);
-
+    m_GeneralWidgets.referencedEntityCB = new KComboBox();
     generalLayout->addWidget(m_GeneralWidgets.referencedEntityCB, 1, 1);
 
-    m_GeneralWidgets.actionGB = new QGroupBox(i18n("Actions"), page);
+    m_GeneralWidgets.actionGB = new QGroupBox(i18n("Actions"));
+    topLayout->addWidget(m_GeneralWidgets.actionGB);
 
     QGridLayout* actionLayout = new QGridLayout(m_GeneralWidgets.actionGB);
     generalLayout->setSpacing(spacingHint());
     generalLayout->setMargin(fontMetrics().height());
 
-    m_GeneralWidgets.onUpdateL = new QLabel(i18n("On Update"), page);
+    m_GeneralWidgets.onUpdateL = new QLabel(i18n("On Update"));
     actionLayout->addWidget(m_GeneralWidgets.onUpdateL, 0, 0);
 
     m_GeneralWidgets.updateActionCB = new KComboBox(page);
     actionLayout->addWidget(m_GeneralWidgets.updateActionCB, 0, 1);
 
-    m_GeneralWidgets.onDeleteL = new QLabel(i18n("On Delete"), page);
+    m_GeneralWidgets.onDeleteL = new QLabel(i18n("On Delete"));
     actionLayout->addWidget(m_GeneralWidgets.onDeleteL, 1, 0);
 
-    m_GeneralWidgets.deleteActionCB = new KComboBox(page);
+    m_GeneralWidgets.deleteActionCB = new KComboBox();
     actionLayout->addWidget(m_GeneralWidgets.deleteActionCB, 1, 1);
 
     // set the name
@@ -251,7 +254,7 @@ void UMLForeignKeyConstraintDialog::setupGeneralPage()
     UMLEntity* referencedEntity = m_pForeignKeyConstraint->getReferencedEntity();
 
     int index;
-    if (referencedEntity != NULL) {
+    if (referencedEntity != 0) {
         index = m_GeneralWidgets.referencedEntityCB->findText(referencedEntity->name());
         if (index != -1)
             m_GeneralWidgets.referencedEntityCB->setCurrentIndex(index);
@@ -280,36 +283,49 @@ void UMLForeignKeyConstraintDialog::setupGeneralPage()
 void UMLForeignKeyConstraintDialog::setupColumnPage()
 {
     //setup Columns page
-    KVBox * page = new KVBox();
+    QWidget* page = new QWidget();
+    QVBoxLayout* topLayout = new QVBoxLayout();
+    page->setLayout(topLayout);
+
     pageColumn = createPage(i18n("Columns"), i18n("Columns"),
                             Icon_Utils::it_Properties_Columns, page);
 
-    m_ColumnWidgets.mappingTW = new QTreeWidget(page);
+    m_ColumnWidgets.mappingTW = new QTreeWidget();
+    topLayout->addWidget(m_ColumnWidgets.mappingTW);
 
     QStringList headers;
     headers << i18nc("column header local", "Local") << i18nc("column header referenced", "Referenced");
     m_ColumnWidgets.mappingTW->setHeaderLabels(headers);
 
-    QWidget* columns = new QWidget(page);
+    QWidget* columns = new QWidget();
+    topLayout->addWidget(columns);
     QGridLayout* columnsLayout = new QGridLayout(columns);
 
-    m_ColumnWidgets.localColumnL = new QLabel(i18n("Local Column"), page);
+    m_ColumnWidgets.localColumnL = new QLabel(i18n("Local Column"));
     columnsLayout->addWidget(m_ColumnWidgets.localColumnL, 0, 0);
 
-    m_ColumnWidgets.localColumnCB = new KComboBox(page);
+    m_ColumnWidgets.localColumnCB = new KComboBox();
     columnsLayout->addWidget(m_ColumnWidgets.localColumnCB, 0, 1);
 
-    m_ColumnWidgets.referencedColumnL = new QLabel(i18n("Referenced Column"), page);
+    m_ColumnWidgets.referencedColumnL = new QLabel(i18n("Referenced Column"));
     columnsLayout->addWidget(m_ColumnWidgets.referencedColumnL, 1, 0);
 
-    m_ColumnWidgets.referencedColumnCB = new KComboBox(page);
+    m_ColumnWidgets.referencedColumnCB = new KComboBox();
     columnsLayout->addWidget(m_ColumnWidgets.referencedColumnCB, 1, 1);
 
+#if QT_VERSION >= 0x050000
+    QDialogButtonBox* buttonBox = new QDialogButtonBox();
+    m_ColumnWidgets.addPB = buttonBox->addButton(i18n("&Add"), QDialogButtonBox::ActionRole);
+    connect(m_ColumnWidgets.addPB, SIGNAL(clicked()), this, SLOT(slotAddPair()));
+    m_ColumnWidgets.removePB = buttonBox->addButton(i18n("&Delete"), QDialogButtonBox::ActionRole);
+    connect(m_ColumnWidgets.removePB, SIGNAL(clicked()), this, SLOT(slotDeletePair()));
+#else
     KDialogButtonBox* buttonBox = new KDialogButtonBox(page);
     m_ColumnWidgets.addPB = buttonBox->addButton(i18n("&Add"), KDialogButtonBox::ActionRole, this,
                             SLOT(slotAddPair()));
     m_ColumnWidgets.removePB = buttonBox->addButton(i18n("&Delete"), KDialogButtonBox::ActionRole, this,
                                SLOT(slotDeletePair()));
+#endif
 
     columnsLayout->addWidget(buttonBox, 2, 1);
 
@@ -404,15 +420,16 @@ void UMLForeignKeyConstraintDialog::refillReferencedAttributeCB()
 
     // fill the combo boxes
 
-    UMLObject* uo = m_doc->findUMLObject(m_GeneralWidgets.referencedEntityCB->currentText(),
-                                         UMLObject::ot_Entity);
+    UMLObject* uo = m_doc->findUMLObjectRecursive(Uml::ModelType::EntityRelationship,
+                                                  m_GeneralWidgets.referencedEntityCB->currentText(),
+                                                  UMLObject::ot_Entity);
 
-    UMLEntity* ue = static_cast<UMLEntity*>(uo);
+    UMLEntity* ue = uo->asUMLEntity();
 
     if (ue) {
         UMLClassifierListItemList ual = ue->getFilteredList(UMLObject::ot_EntityAttribute);
         foreach(UMLClassifierListItem* att, ual) {
-            m_pReferencedAttributeList.append(static_cast<UMLEntityAttribute*>(att));
+            m_pReferencedAttributeList.append(att->asUMLEntityAttribute());
             m_ColumnWidgets.referencedColumnCB->addItem(att->toString(Uml::SignatureType::SigNoVis));
         }
     }
@@ -423,12 +440,12 @@ void UMLForeignKeyConstraintDialog::refillLocalAttributeCB()
     m_pLocalAttributeList.clear();
     m_ColumnWidgets.localColumnCB->clear();
     // fill the combo boxes
-    UMLEntity* ue = static_cast<UMLEntity*>(m_pForeignKeyConstraint->parent());
+    UMLEntity* ue = m_pForeignKeyConstraint->umlParent()->asUMLEntity();
 
     if (ue) {
         UMLClassifierListItemList ual = ue->getFilteredList(UMLObject::ot_EntityAttribute);
         foreach(UMLClassifierListItem* att, ual) {
-            m_pLocalAttributeList.append(static_cast<UMLEntityAttribute*>(att));
+            m_pLocalAttributeList.append(att->asUMLEntityAttribute());
             m_ColumnWidgets.localColumnCB->addItem(att->toString(Uml::SignatureType::SigNoVis));
         }
     }
@@ -452,10 +469,9 @@ void UMLForeignKeyConstraintDialog::slotResetWidgetState()
     }
 
     // get index of selected Attribute in List Box
-    if (m_ColumnWidgets.mappingTW->currentItem() == NULL) {
+    if (m_ColumnWidgets.mappingTW->currentItem() == 0) {
         m_ColumnWidgets.removePB->setEnabled(false);
     }
 }
 
-#include "umlforeignkeyconstraintdialog.moc"
 
